Files
TheRock/debug-tools/rocgdb/source/gdb/testsuite/gdb.rocm/aspace-watchpoint.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

108 lines
3.3 KiB
C++

/* Copyright (C) 2022-2024 Free Software Foundation, Inc.
Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights reserved.
This file is part of GDB.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
Test writes to default address space (global memory) as well as
private_lane address space to test the watchpoints in different
address spaces.
The WAIT_MEM macro is used to force out a watchpoint hit event being
reported by the target on specific synchronisation points for a more
controlled execution. */
#include <hip/hip_runtime.h>
#include <stdio.h>
#include <stdlib.h>
#define CHECK(cmd) \
{ \
hipError_t error = cmd; \
if (error != hipSuccess) \
{ \
fprintf (stderr, "error: '%s'(%d) at %s:%d\n", \
hipGetErrorString (error), error, __FILE__, __LINE__); \
exit (EXIT_FAILURE); \
} \
}
#define WAIT_MEM \
asm volatile (".if .amdgcn.gfx_generation_number < 10\n" \
" s_waitcnt 0\n" \
".elseif .amdgcn.gfx_generation_number < 11\n" \
" s_waitcnt_vscnt null, 0\n" \
".else\n" \
" s_wait_idle\n" \
".endif")
__device__ void
change_memory (char *private_ptr, int *global_ptr)
{
/* Test if an address context (thread and SIMD lane) is handled
correctly depending on the address space that that address
belongs to. */
*(private_ptr + 3) = 'c';
WAIT_MEM;
*private_ptr = 'c';
WAIT_MEM;
*global_ptr = 2;
WAIT_MEM;
}
/* Kernel entry point. Initialise and change the addresses in different
address spaces to trigger hardware watchpoints. */
__global__ void
kernel (int *global_ptr)
{
/* Initialise an array in the private_lane address space. */
char array[4] = {'a', 'a', 'a', 'a'};
/* Only testing watchpoints in global and private_lane address
spaces. */
array[3] = 'b';
WAIT_MEM;
array[0] = 'b';
WAIT_MEM;
*global_ptr = 1;
WAIT_MEM;
change_memory (&array[0], global_ptr);
array[3] = 'd';
WAIT_MEM;
*global_ptr = 3;
WAIT_MEM;
}
int
main (int argc, char* argv[])
{
int *global_ptr;
CHECK (hipMalloc (&global_ptr, 4));
int init_value_h = 0;
CHECK (hipMemcpy (global_ptr, &init_value_h, sizeof (init_value_h),
hipMemcpyHostToDevice));
kernel<<<2, 1, 0>>> (global_ptr);
CHECK (hipDeviceSynchronize ());
return 0;
}